@@ -38,12 +38,12 @@ _pkg_config = {
     'py_version':         0x030607,
     'qt_framework':       0,
     'sip_bin':            '/usr/bin/sip',
-    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4 LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'sip_config_args':    'CFLAGS=-march=x86-64 -mtune=generic -O2 -pipe -fno-plt LFLAGS=-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'sip_inc_dir':        '/usr/include/python3.6m',
     'sip_module_dir':     '/usr/lib/python3.6/site-packages',
     'sip_root_dir':       '/usr/lib/python3.6/site-packages',
-    'sip_version':        0x041313,
-    'sip_version_str':    '4.19.19',
+    'sip_version':        0x041317,
+    'sip_version_str':    '4.19.23',
     'universal':          ''
 }
 
@@ -51,7 +51,7 @@ _default_macros = {
     'AIX_SHLIB':                '',
     'AR':                       'ar cqs',
     'CC':                       'gcc',
-    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fstack-protector-strong --param=ssp-buffer-size=4',
+    'CFLAGS':                   '-march=x86-64 -mtune=generic -O2 -pipe -fno-plt',
     'CFLAGS_APP':               '',
     'CFLAGS_CONSOLE':           '',
     'CFLAGS_DEBUG':             '-g',
@@ -100,7 +100,7 @@ _default_macros = {
     'INCDIR':                   '',
     'INCDIR_OPENGL':            '/usr/X11R6/include',
     'INCDIR_X11':               '/usr/X11R6/include',
-    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro',
+    'LFLAGS':                   '-Wl,-O1,--sort-common,--as-needed,-z,relro,-z,now',
     'LFLAGS_CONSOLE':           '',
     'LFLAGS_CONSOLE_DLL':       '',
     'LFLAGS_DEBUG':             '',
